=== modified file 'errors.py'
--- errors.py	2006-08-07 03:07:35 +0000
+++ errors.py	2006-12-04 14:32:43 +0000
@@ -15,11 +15,14 @@
 #    along with this program; if not, write to the Free Software
 #    Foundation, Inc., 59 Temple Place, Suite 330, Boston, MA  02111-1307  USA
 
+import os
+
 class NoPyBaz(Exception):
     def __init__(self):
         Exception.__init__(self, "PyBaz is not installed.")
 try:
     from bzrlib.errors import BzrCommandError as CommandError
+    from bzrlib.errors import BzrError
 except ImportError:
     class CommandError(Exception):
         pass
@@ -28,6 +31,17 @@
     """Failed applying patch!"""
 
 
+class PatchInvokeError(BzrError):
+
+    _fmt = """Error invoking patch: %(errstr)s\n%(stderr)s"""
+    internal_error = False
+
+    def __init__(self, e, stderr):
+        self.exception = e
+        self.errstr = os.strerror(e.errno)
+        self.stderr = stderr
+
+
 class NoColor(Exception):
     """Color not available on this terminal."""
 

=== modified file 'shelf.py'
--- shelf.py	2006-08-07 03:07:35 +0000
+++ shelf.py	2006-12-04 14:32:43 +0000
@@ -2,7 +2,7 @@
 import sys
 import subprocess
 from datetime import datetime
-from errors import CommandError, PatchFailed
+from errors import CommandError, PatchFailed, PatchInvokeError
 from hunk_selector import ShelveHunkSelector, UnshelveHunkSelector
 from patchsource import PatchSource, FilePatchSource
 from bzrlib.osutils import rename
@@ -255,10 +255,14 @@
         else:
             stdout = stderr = None
 
-        process = subprocess.Popen(args, stdin=subprocess.PIPE, stdout=stdout,
-                        stderr=stderr)
-        for patch in patches:
-            process.stdin.write(str(patch))
+        try:
+            process = subprocess.Popen(args, stdin=subprocess.PIPE,
+                                       stdout=stdout, stderr=stderr)
+            for patch in patches:
+                process.stdin.write(str(patch))
+
+        except IOError, e:
+            raise PatchInvokeError(e, process.stderr.read())
 
         process.communicate()
 

